@@ -145,7 +145,6 @@ class BootLoaderConfigGrub2(BootLoaderConfigBase):
         self.cmdline = None
         self.iso_boot = False
         self.shim_fallback_setup = False
-        self.validate_use_of_linuxefi = False
 
     def write(self):
         """
@@ -241,11 +240,11 @@ class BootLoaderConfigGrub2(BootLoaderConfigBase):
             ]
         )
 
-        if self.validate_use_of_linuxefi:
-            # On systems that uses GRUB_USE_LINUXEFI with grub2 version
-            # less than 2.04 there is no support for dynamic EFI
-            # environment checking. In this condition we change the
-            # grub config to add this support as follows:
+        if self.firmware.efi_mode():
+            # On systems that are configured to use EFI with a grub2
+            # version less than 2.04 there is no support for dynamic
+            # EFI environment checking. In this condition we change
+            # the grub config to add this support as follows:
             #
             # * Apply only on grub < 2.04
             #    1. Modify grub.cfg to set linux/initrd as variables
@@ -262,11 +261,11 @@ class BootLoaderConfigGrub2(BootLoaderConfigBase):
                 with open(config_file) as grub_config_file:
                     grub_config = grub_config_file.read()
                     grub_config = re.sub(
-                        r'([ \t]+)linux[efi]*([ \t]+)', r'\1$linux\2',
+                        r'([ \t]+)linux(efi|16)*([ \t]+)', r'\1$linux\3',
                         grub_config
                     )
                     grub_config = re.sub(
-                        r'([ \t]+)initrd[efi]*([ \t]+)', r'\1$initrd\2',
+                        r'([ \t]+)initrd(efi|16)*([ \t]+)', r'\1$initrd\3',
                         grub_config
                     )
                 with open(config_file, 'w') as grub_config_file:
@@ -294,6 +293,21 @@ class BootLoaderConfigGrub2(BootLoaderConfigBase):
                 with open(config_file, 'w') as grub_config_file:
                     grub_config_file.write(grub_config)
 
+                if self.firmware.efi_mode():
+                    vendor_grubenv_file = \
+                        Defaults.get_vendor_grubenv(self.efi_mount.mountpoint)
+                    if vendor_grubenv_file:
+                        with open(vendor_grubenv_file) as vendor_grubenv:
+                            grubenv = vendor_grubenv.read()
+                            grubenv = grubenv.replace(
+                                'root={0}'.format(boot_options.get(
+                                    'root_device')
+                                ),
+                                self.root_reference
+                            )
+                        with open(vendor_grubenv_file, 'w') as vendor_grubenv:
+                            vendor_grubenv.write(grubenv)
+
         if self.firmware.efi_mode():
             self._copy_grub_config_to_efi_path(
                 self.efi_mount.mountpoint, config_file
@@ -623,7 +637,6 @@ class BootLoaderConfigGrub2(BootLoaderConfigBase):
                 if use_linuxefi_implemented.returncode == 0:
                     grub_default_entries['GRUB_USE_LINUXEFI'] = 'true'
                     grub_default_entries['GRUB_USE_INITRDEFI'] = 'true'
-                    self.validate_use_of_linuxefi = True
         if self.xml_state.build_type.get_btrfs_root_is_snapshot():
             grub_default_entries['SUSE_BTRFS_SNAPSHOT_BOOTING'] = 'true'
         if self.custom_args.get('boot_is_crypto'):
