@@ -419,11 +419,16 @@ class TestBootLoaderConfigGrub2:
     @patch.object(BootLoaderConfigGrub2, '_mount_system')
     @patch.object(BootLoaderConfigGrub2, '_copy_grub_config_to_efi_path')
     @patch('kiwi.bootloader.config.grub2.Command.run')
+    @patch('kiwi.bootloader.config.grub2.CommandCapabilities.check_version')
     @patch('kiwi.bootloader.config.grub2.Path.which')
+    @patch('kiwi.defaults.Defaults.get_vendor_grubenv')
     def test_setup_disk_image_config(
-        self, mock_Path_which, mock_Command_run,
+        self, mock_get_vendor_grubenv, mock_Path_which,
+        mock_CommandCapabilities_check_version, mock_Command_run,
         mock_copy_grub_config_to_efi_path, mock_mount_system
     ):
+        mock_CommandCapabilities_check_version.return_value = True
+        mock_get_vendor_grubenv.return_value = 'grubenv'
         mock_Path_which.return_value = '/path/to/grub2-mkconfig'
         self.firmware.efi_mode = Mock(
             return_value='uefi'
@@ -455,9 +460,10 @@ class TestBootLoaderConfigGrub2:
             mock_copy_grub_config_to_efi_path.assert_called_once_with(
                 'efi_mount_point', 'root_mount_point/boot/grub2/grub.cfg'
             )
-            file_handle.write.assert_called_once_with(
-                'root=overlay:UUID=ID'
-            )
+            assert file_handle.write.call_args_list == [
+                call('root=overlay:UUID=ID'),
+                call('root=overlay:UUID=ID')
+            ]
 
     @patch.object(BootLoaderConfigGrub2, '_mount_system')
     @patch.object(BootLoaderConfigGrub2, '_copy_grub_config_to_efi_path')
@@ -474,7 +480,6 @@ class TestBootLoaderConfigGrub2:
         self.firmware.efi_mode = Mock(
             return_value='uefi'
         )
-        self.bootloader.validate_use_of_linuxefi = True
         self.bootloader.root_mount = Mock()
         self.bootloader.root_mount.mountpoint = 'root_mount_point'
         self.bootloader.efi_mount = Mock()
@@ -486,8 +491,10 @@ class TestBootLoaderConfigGrub2:
                 [
                     '\tlinuxefi ${rel_dirname}/${basename} ...',
                     '\tlinux ${rel_dirname}/${basename} ...',
+                    '\tlinux16 ${rel_dirname}/${basename} ...',
                     '\tinitrdefi ${rel_dirname}/${initrd}',
-                    '\tinitrd ${rel_dirname}/${initrd}'
+                    '\tinitrd ${rel_dirname}/${initrd}',
+                    '\tinitrd16 ${rel_dirname}/${initrd}'
                 ]
             )
             self.bootloader.setup_disk_image_config(
@@ -510,6 +517,8 @@ class TestBootLoaderConfigGrub2:
                 call(
                     '\t$linux ${rel_dirname}/${basename} ...\n'
                     '\t$linux ${rel_dirname}/${basename} ...\n'
+                    '\t$linux ${rel_dirname}/${basename} ...\n'
+                    '\t$initrd ${rel_dirname}/${initrd}\n'
                     '\t$initrd ${rel_dirname}/${initrd}\n'
                     '\t$initrd ${rel_dirname}/${initrd}'
                 )
